package com.mt.wms.basic.controller;

import com.mt.wms.basic.params.LocationInfoParam;
import com.mt.wms.basic.params.LocationInfoQueryParam;
import com.mt.wms.basic.service.LocationInfoService;
import com.mt.wms.basic.vo.LocationInfoVo;
import com.mt.wms.core.base.BaseController;
import com.mt.wms.core.constants.CommonConstant;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.utils.IDGenerator;
import com.mt.wms.core.validator.groups.AddGroup;
import com.mt.wms.core.validator.groups.PageGroup;
import com.mt.wms.core.validator.groups.UpdateGroup;
import com.mt.wms.core.vo.IdVo;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.groups.Default;
import java.util.List;

/**
 * @Author: liguanghao
 * @Date: 2021/11/9 13:03
 * @Version 1.0
 */
@RestController
@RequestMapping(CommonConstant.API_MODULE_BASE + "locationInfo")
@Slf4j
@Api(value = "库位基础信息管理", tags = "库位基础信息管理", hidden = false)
public class LocationInfoController extends BaseController {

    @Autowired
    private LocationInfoService locationInfoService;
    @PostMapping(value = "get")
    @ApiOperation(value = "获取库位信息")
    private R<LocationInfoVo> get(@Validated @RequestBody IdParam idParam) {
        return locationInfoService.get(idParam);
    }

    @PostMapping(value = "list")
    @ApiOperation(value = "获取库位列表")
    private R<List<LocationInfoVo>> list(@Validated({Default.class}) @RequestBody LocationInfoQueryParam locationInfoQueryParam) {
        return locationInfoService.list(locationInfoQueryParam);
    }

    @PostMapping(value = "page")
    @ApiOperation(value = "获取分页库位")
    private R<PageVo<LocationInfoVo>> page(@Validated({PageGroup.class, Default.class}) @RequestBody LocationInfoQueryParam locationInfoQueryParam) {
        return locationInfoService.page(locationInfoQueryParam);
    }

    @PostMapping(value = "add")
    @ApiOperation(value = "新增")
    private R<IdVo> add(@Validated({AddGroup.class, Default.class}) @RequestBody LocationInfoParam locationInfoParam) {
        return locationInfoService.add(locationInfoParam);
    }

    @PostMapping(value = "update")
    @ApiOperation(value = "更新")
    private R<IdVo> update(@Validated({UpdateGroup.class, Default.class}) @RequestBody LocationInfoParam locationInfoParam) {
        return locationInfoService.update(locationInfoParam);
    }

    @PostMapping(value = "delete")
    @ApiOperation(value = "删除")
    private R<IdVo> delete(@Validated @RequestBody IdParam idParam) {
        return locationInfoService.delete(idParam);
    }

    @PostMapping(value = "codeGenerator")
    @ApiOperation(value = "编码生成")
    private R<String> codeGenerator(){
        return successful(IDGenerator.gen("KW", "yyyyMMddHHmm", 2, "LOCATION_CODE"));
    }

}
