package com.mt.wms.basic.controller;


import com.mt.wms.basic.params.WarehouseParam;
import com.mt.wms.basic.params.WarehouseQueryParam;
import com.mt.wms.basic.service.WarehouseService;
import com.mt.wms.basic.vo.WarehouseVo;
import com.mt.wms.core.base.BaseController;
import com.mt.wms.core.constants.CommonConstant;
import com.mt.wms.core.params.EnabledParam;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.utils.IDGenerator;
import com.mt.wms.core.validator.groups.AddGroup;
import com.mt.wms.core.validator.groups.PageGroup;
import com.mt.wms.core.validator.groups.UpdateGroup;
import com.mt.wms.core.vo.IdVo;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.groups.Default;
import java.util.List;

/**
 * @Author: liguanghao
 * @Date: 2021/9/28 17:00
 * @Version 1.0
 */
@RestController
@RequestMapping(CommonConstant.API_MODULE_BASE + "warehouse")
@Slf4j
@Api(value = "缓存区管理", tags = "缓存区管理", hidden = false)
public class WarehouseController extends BaseController {

    @Autowired
    private WarehouseService warehouseService;
    @PostMapping(value = "get")
    @ApiOperation(value = "获取缓存区")
    private R<WarehouseVo> get(@Validated @RequestBody IdParam idParam) {
        return warehouseService.get(idParam);
    }

    @PostMapping(value = "list")
    @ApiOperation(value = "获取缓存区列表")
    private R<List<WarehouseVo>> list(@Validated({Default.class}) @RequestBody WarehouseQueryParam warehouseQueryParam) {
        return warehouseService.list(warehouseQueryParam);
    }

    @PostMapping(value = "page")
    @ApiOperation(value = "获取分页缓存区")
    private R<PageVo<WarehouseVo>> page(@Validated({PageGroup.class, Default.class}) @RequestBody WarehouseQueryParam warehouseQueryParam) {
        return warehouseService.page(warehouseQueryParam);
    }

    @PostMapping(value = "add")
    @ApiOperation(value = "新增")
    private R<IdVo> add(@Validated({AddGroup.class, Default.class}) @RequestBody WarehouseParam warehouseParam) {
        return warehouseService.add(warehouseParam);
    }

    @PostMapping(value = "update")
    @ApiOperation(value = "更新")
    private R<IdVo> update(@Validated({UpdateGroup.class, Default.class}) @RequestBody WarehouseParam warehouseParam) {
        return warehouseService.update(warehouseParam);
    }

    @PostMapping(value = "delete")
    @ApiOperation(value = "删除缓存区")
    private R<IdVo> delete(@Validated @RequestBody IdParam idParam) {
        return warehouseService.delete(idParam);
    }

    @PostMapping(value = "codeGenerator")
    @ApiOperation(value = "编码生成")
    private R<String> codeGenerator(){
        return successful(IDGenerator.gen("HC", "yyyyMMddHHmm", 2, "WAREHOUSE_CODE"));
    }
}
