package com.mt.wms.basic.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mt.wms.basic.params.KilnInfoParam;
import com.mt.wms.basic.params.KilnInfoQueryParam;
import com.mt.wms.basic.service.KilnInfoService;
import com.mt.wms.basic.vo.KilnInfoVo;
import com.mt.wms.core.api.Assert;
import com.mt.wms.core.base.BaseService;
import com.mt.wms.core.dal.entity.KilnInfo;
import com.mt.wms.core.dal.service.KilnInfoServiceBiz;
import com.mt.wms.core.errorcode.ApiErrorCode;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.vo.IdVo;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author: liguanghao
 * @Date: 2021/11/9 12:16
 * @Version 1.0
 */
@Service
@Transactional
public class KilnInfoServiceImpl extends BaseService implements KilnInfoService {
    @Resource
    private KilnInfoServiceBiz kilnInfoServiceBiz;
    @Override
    public R<KilnInfoVo> get(IdParam idParam) {
        Assert.notNull(ApiErrorCode.INVALID_PARAMETER,idParam.getId());
        KilnInfo kilnInfo = kilnInfoServiceBiz.getById(idParam.getId());
        KilnInfoVo kilnInfoVo=KilnInfoVo.builder().build();
        BeanUtils.copyProperties(kilnInfo,kilnInfoVo);
        return successful(kilnInfoVo);
    }

    @Override
    public R<List<KilnInfoVo>> list(KilnInfoQueryParam kilnInfoQueryParam) {
        QueryWrapper<KilnInfo> wrapper=new QueryWrapper<>();
        wrapper.eq(KilnInfo.VALID,1);
        List<KilnInfo> kilnInfoList = kilnInfoServiceBiz.list(wrapper);
        List<KilnInfoVo> kilnInfoVoList = com.mt.wms.core.utils.BeanUtils.copyList(kilnInfoList, KilnInfoVo.class);
        return successful(kilnInfoVoList);
    }

    @Override
    public R<PageVo<KilnInfoVo>> page(KilnInfoQueryParam kilnInfoQueryParam) {
        QueryWrapper<KilnInfo> wrapper=new QueryWrapper<>();
        wrapper.eq(KilnInfo.VALID,1);
        Page<KilnInfo> page = kilnInfoServiceBiz.page(new Page<>(kilnInfoQueryParam.getCurrent(), kilnInfoQueryParam.getSize()), wrapper);
        return successful(new PageVo<>(page,KilnInfoVo.class));
    }

    @Override
    public R<IdVo> add(KilnInfoParam kilnInfoParam) {
        QueryWrapper<KilnInfo> wrapper=new QueryWrapper<>();

        KilnInfo kilnInfo=new KilnInfo();
        BeanUtils.copyProperties(kilnInfoParam,kilnInfo);
        setCommonField(kilnInfo);
        kilnInfoServiceBiz.save(kilnInfo);
        return successful(IdVo.builder().id(kilnInfo.getId()).build());
    }

    @Override
    public R<IdVo> update(KilnInfoParam kilnInfoParam) {
        KilnInfo kilnInfo = kilnInfoServiceBiz.getById(kilnInfoParam.getId());
        if (!kilnInfoParam.getKilnName().equals(kilnInfo.getKilnName())){
            QueryWrapper<KilnInfo> wrapper=new QueryWrapper<>();
            wrapper.eq(KilnInfo.KILN_NAME,kilnInfoParam.getKilnName());
            wrapper.eq(KilnInfo.VALID,1);
            Assert.eqZero(kilnInfoServiceBiz.count(wrapper),"车辆名称已存在！");
        }
        KilnInfo updatewKilnInfo=new KilnInfo();
        BeanUtils.copyProperties(kilnInfoParam,updatewKilnInfo);
        setUpdateCommonField(updatewKilnInfo);
        kilnInfoServiceBiz.updateById(updatewKilnInfo);
        return successful(IdVo.builder().id(updatewKilnInfo.getId()).build());
    }

    @Override
    public R<IdVo> delete(IdParam idParam) {
        kilnInfoServiceBiz.removeById(idParam.getId());
        return successful(IdVo.builder().id(idParam.getId()).build());
    }
}
