package com.mt.wms.basic.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mt.wms.basic.params.WarehouseParam;
import com.mt.wms.basic.params.WarehouseQueryParam;
import com.mt.wms.basic.service.WarehouseService;
import com.mt.wms.basic.vo.WarehouseVo;
import com.mt.wms.core.api.Assert;
import com.mt.wms.core.base.BaseService;
import com.mt.wms.core.dal.entity.Warehouse;
import com.mt.wms.core.dal.service.WarehouseServiceBiz;
import com.mt.wms.core.errorcode.ApiErrorCode;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.vo.IdVo;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author: liguanghao
 * @Date: 2021/9/28 15:45
 * @Version 1.0
 */
@Service
@Transactional
public class WarehouseServiceImpl extends BaseService implements WarehouseService {

    @Resource
    private WarehouseServiceBiz warehouseServiceBiz;
    @Override
    public R<WarehouseVo> get(IdParam idParam) {
        Assert.notNull(ApiErrorCode.INVALID_PARAMETER,idParam.getId());
        Warehouse warehouse = warehouseServiceBiz.getById(idParam.getId());
        WarehouseVo warehouseVo = WarehouseVo.builder().build();
        BeanUtils.copyProperties(warehouse,warehouseVo);
        return successful(warehouseVo);
    }

    @Override
    public R<List<WarehouseVo>> list(WarehouseQueryParam warehouseQueryParam) {
        QueryWrapper<Warehouse> wrapper=new QueryWrapper<>();
        wrapper.eq(Warehouse.VALID,1);
        List<Warehouse> warehouseList = warehouseServiceBiz.list(wrapper);
        List<WarehouseVo> warehouseVoList = com.mt.wms.core.utils.BeanUtils.copyList(warehouseList, WarehouseVo.class);
        return successful(warehouseVoList);
    }

    @Override
    public R<PageVo<WarehouseVo>> page(WarehouseQueryParam warehouseQueryParam) {
        QueryWrapper<Warehouse> wrapper=new QueryWrapper<>();
        wrapper.like(StringUtils.isNotBlank(warehouseQueryParam.getCode()),Warehouse.CODE,warehouseQueryParam.getCode())
                .orderByDesc(Warehouse.CREATE_TIME);
        Page<Warehouse> page = warehouseServiceBiz.page(new Page<>(warehouseQueryParam.getCurrent(), warehouseQueryParam.getSize()), wrapper);
        return successful(new PageVo<>(page,WarehouseVo.class));
    }

    @Override
    public R<IdVo> add(WarehouseParam warehouseParam) {
        QueryWrapper<Warehouse> wrapper=new QueryWrapper<>();

        Warehouse warehouse=new Warehouse();
        BeanUtils.copyProperties(warehouseParam,warehouse);
        setCommonField(warehouse);
        warehouseServiceBiz.save(warehouse);
        return successful(IdVo.builder().id(warehouse.getId()).build());
    }

    @Override
    public R<IdVo> update(WarehouseParam warehouseParam) {
        Warehouse warehouse = warehouseServiceBiz.getById(warehouseParam.getId());
        if (!warehouseParam.getCode().equals(warehouse.getCode())){
            QueryWrapper<Warehouse> wrapper=new QueryWrapper<>();
            wrapper.eq(Warehouse.CODE,warehouseParam.getCode());
            wrapper.eq(Warehouse.VALID,1);
            Assert.eqZero(warehouseServiceBiz.count(wrapper),"缓存区编码已存在！");
        }
        Warehouse updateWarehouse=new Warehouse();
        BeanUtils.copyProperties(warehouseParam,updateWarehouse);
        setUpdateCommonField(updateWarehouse);
        warehouseServiceBiz.updateById(updateWarehouse);
        return successful(IdVo.builder().id(updateWarehouse.getId()).build());
    }

    @Override
    public R<IdVo> delete(IdParam idParam) {
        warehouseServiceBiz.removeById(idParam.getId());
        return successful(IdVo.builder().id(idParam.getId()).build());
    }
}
