package com.mt.wms.core.dal.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 任务表
 * </p>
 *
 * @author mt
 * @since 2021-12-14
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("t_curr_task")
public class CurrTask extends Model<CurrTask> {

    private static final long serialVersionUID = 1L;

      @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 删除标志，是否有效:1 可用 0不可用，2停止
     */
    @TableField("valid")
    @TableLogic
    private Integer valid;

    /**
     * 添加时间，每次修改记录要更新记录新增时间
     */
    @TableField("create_time")
    private LocalDateTime createTime;

    /**
     * 创建人id
     */
    @TableField("creator_id")
    private Integer creatorId;

    /**
     * 更新人id
     */
    @TableField("updater_id")
    private Integer updaterId;

    /**
     * 修改时间，更具修改时间来判断下次执行顺序，第一次修改时间和新增时间相同
     */
    @TableField("update_time")
    private LocalDateTime updateTime;

    /**
     * 版本号 默认为 1
     */
    @TableField("version")
    @Version
    private String version;

    /**
     * 状态：	0等待执行，1执行中，2执行完成
     */
    @TableField("status")
    private Integer status;

    /**
     * 内部编码，系统自动生成
     */
    @TableField("inter_code")
    private String interCode;

    /**
     * 是否自动执行：	0手动，1自动，如果是自动任务这里要监控进出和到缓存区的调度任务
     */
    @TableField("is_auto")
    private Integer isAuto;

    /**
     * 任务流程ID，关联流程表：t_auto_exe_task
     */
    @TableField("auto_exe_task_id")
    private Long autoExeTaskId;

    /**
     * 工业炉id，关联设备工业炉表：t_kiln_info
     */
    @TableField("kiln_id")
    private Long kilnId;

    /**
     * 工业炉名称
     */
    @TableField("kiln_name")
    private String kilnName;

    /**
     * 工艺号ID，关联工艺号表：t_craft_info
     */
    @TableField("craft_code_id")
    private Long craftCodeId;

    /**
     * 工艺号对应PLC值
     */
    @TableField("plc_value")
    private Integer plcValue;

    /**
     * 开始加工时间
     */
    @TableField("begin_time")
    private LocalDateTime beginTime;

    /**
     * 加工结束时间
     */
    @TableField("end_time")
    private LocalDateTime endTime;

    /**
     * 进炉状态：	0准备进炉，1正在加工，2加工完成
     */
    @TableField("is_in")
    private Integer isIn;

    /**
     * 调度任务ID，关联调度表：t_run_task
     */
    @TableField("run_task_id")
    private Long runTaskId;

    /**
     * 开始位置
     */
    @TableField("start_position")
    private String startPosition;

    /**
     * 目标位置指的是工业炉的位置
     */
    @TableField("target_position")
    private String targetPosition;

    /**
     * 是否缓存，如果当前指的工业炉正在加工，系统自动分配货物到缓存位置，		      并且记录缓存库位，这是当指定工业炉加工完成后系统先判断是否当前缓存有当前等待执行的任务，然后按照先来先执行原则（等待多个任务）自动调用车辆来执行
     */
    @TableField("is_cache")
    private Integer isCache;

    /**
     * 缓存状态状态：	0准备进入缓存区，1正在进入缓存区，2缓存完成
     */
    @TableField("cache_satatus")
    private Integer cacheSatatus;

    /**
     * 调度任务ID，关联调度表：t_run_task
     */
    @TableField("cache_run_task_id")
    private Long cacheRunTaskId;

    /**
     * 库位id，关联库位表：t_location
     */
    @TableField("location_id")
    private Long locationId;

    /**
     * 库位名称
     */
    @TableField("location_name")
    private String locationName;

    /**
     * 出炉状态：	0准备出炉，1正在加工，2加工完成
     */
    @TableField("is_out")
    private Integer isOut;

    /**
     * 调度任务ID，关联调度表：t_run_task
     */
    @TableField("out_run_task_id")
    private Long outRunTaskId;

    /**
     * 开始位置
     */
    @TableField("out_start_position")
    private String outStartPosition;

    /**
     * 目标位置，指缓存位置
     */
    @TableField("out_target_position")
    private String outTargetPosition;

    /**
     * 任务编码
     */
    @TableField("task_code")
    private String taskCode;

    /**
     * 生产单号 APMS生成生产单后返回
     */
    @TableField("sheet_no")
    private String sheetNo;

    /**
     * 任务类型：0:入库到工业炉，1:入库到缓存区，2出库到	工业炉到缓存区，3缓存区出库
     */
    @TableField("task_type")
    private Integer taskType;

    /**
     * 加工类型：0 初始加工，1 复加工
     */
    @TableField("process_type")
    private Integer processType;


    public static final String ID = "id";

    public static final String VALID = "valid";

    public static final String CREATE_TIME = "create_time";

    public static final String CREATOR_ID = "creator_id";

    public static final String UPDATER_ID = "updater_id";

    public static final String UPDATE_TIME = "update_time";

    public static final String VERSION = "version";

    public static final String STATUS = "status";

    public static final String INTER_CODE = "inter_code";

    public static final String IS_AUTO = "is_auto";

    public static final String AUTO_EXE_TASK_ID = "auto_exe_task_id";

    public static final String KILN_ID = "kiln_id";

    public static final String KILN_NAME = "kiln_name";

    public static final String CRAFT_CODE_ID = "craft_code_id";

    public static final String PLC_VALUE = "plc_value";

    public static final String BEGIN_TIME = "begin_time";

    public static final String END_TIME = "end_time";

    public static final String IS_IN = "is_in";

    public static final String RUN_TASK_ID = "run_task_id";

    public static final String START_POSITION = "start_position";

    public static final String TARGET_POSITION = "target_position";

    public static final String IS_CACHE = "is_cache";

    public static final String CACHE_SATATUS = "cache_satatus";

    public static final String CACHE_RUN_TASK_ID = "cache_run_task_id";

    public static final String LOCATION_ID = "location_id";

    public static final String LOCATION_NAME = "location_name";

    public static final String IS_OUT = "is_out";

    public static final String OUT_RUN_TASK_ID = "out_run_task_id";

    public static final String OUT_START_POSITION = "out_start_position";

    public static final String OUT_TARGET_POSITION = "out_target_position";

    public static final String TASK_CODE = "task_code";

    public static final String SHEET_NO = "sheet_no";

    public static final String TASK_TYPE = "task_type";

    public static final String PROCESS_TYPE = "process_type";

    @Override
    protected Serializable pkVal() {
        return this.id;
    }

}
