package com.mt.wms.empty.service;

import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import com.mt.wms.empty.params.*;
import com.mt.wms.empty.vo.OrderInfoTaskDetVo;
import com.mt.wms.empty.vo.OrderInfoVo;

import java.util.List;

/**
 * 订单相关服务
 *
 * @author xcc
 * @date 2021年11月8日
 * @since 1.0
 */
public interface OrderInfoService {
    /**
     * APMS推送订单
     *
     * @param apmsPostOrderParam 订单参数
     * @return 操作结果
     */
    R<String> apmsPostOrder(OrderParamForApms apmsPostOrderParam);

    /**
     * 查询当前订单列表
     *
     * @param orderInfoBasePageParam 查询参数
     * @return 分页结果集
     */
    R<PageVo<OrderInfoVo>> page(OrderInfoBasePageParam orderInfoBasePageParam);

    /**
     * 人工创建订单
     *
     * @param orderInfoPersonCreateParam 人工订单参数
     * @return 结果
     */
    R<String> personCreateOrder(OrderInfoPersonCreateParam orderInfoPersonCreateParam);

    /**
     * 获取详细单条信息
     *
     * @param idParam id主键
     * @return 结果
     */
    R<OrderInfoVo> getOne(IdParam idParam);
    /**
     *获取当前订单的详细任务信息
     * @param orderInfoTaskDetParam 标识卡号与订单号
     * @return 结果
     */
    R<PageVo<OrderInfoTaskDetVo>> getTaskInfo(OrderInfoTaskDetParam orderInfoTaskDetParam);

    /**
     * 创建加工订单时查询订单信息
     *
     * @param idenCardNum 标识卡号
     * @return 结果
     */
    R<OrderInfoVo> getTaskInfoByIdenCardNum(String idenCardNum);

    /**
     * 验证传入的详细订单标识卡正确
     *
     * @param detParams 详细订单
     */
    void verifyTaskInfoByIdenCardNum(List<TaskCreateDetParam> detParams);

    /**
     * 完成订单
     *
     * @param idParam id号
     * @return 结果
     */
    R<String> completeOrder(IdParam idParam);

    /**
     * 作废订单
     *
     * @param idParam id号
     * @return 结果
     */
    R<String> voidOrder(IdParam idParam);

    /**
     * APMS作废订单
     *
     * @param idenCardNum 标识卡号
     * @return 结果
     */
    R<String> apmsVoidOrder(String idenCardNum);

    /**
     * APMS返回订单结果
     *
     * @param apmsCompleteOrder 订单检验结果
     * @return 结果
     */
    R<String> apmsCompleteOrder(ApmsCompleteOrder apmsCompleteOrder);

}
