package com.mt.wms.empty.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mt.wms.core.api.Assert;
import com.mt.wms.core.base.BaseService;
import com.mt.wms.core.dal.entity.AutoExeTask;
import com.mt.wms.core.dal.entity.AutoExeTaskHis;
import com.mt.wms.core.dal.entity.CurrTask;
import com.mt.wms.core.dal.service.AutoExeTaskHisServiceBiz;
import com.mt.wms.core.dal.service.AutoExeTaskServiceBiz;
import com.mt.wms.core.dal.service.CurrTaskServiceBiz;
import com.mt.wms.core.errorcode.ApiErrorCode;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.vo.IdVo;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import com.mt.wms.empty.controller.ApmsController;
import com.mt.wms.empty.params.AutoTaskParam;
import com.mt.wms.empty.params.AutoTaskQueryParam;
import com.mt.wms.empty.service.AutoTaskService;
import com.mt.wms.empty.vo.ApmsEndProcessVo;
import com.mt.wms.empty.vo.AutoTaskVo;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author: liguanghao
 * @Date: 2022/3/3 23:18
 * @Version 1.0
 */
@Service
@Transactional
public class AutoTaskServiceImpl extends BaseService implements AutoTaskService {

    private final static Logger logger = LoggerFactory.getLogger(AutoTaskServiceImpl.class);
    @Resource
    private AutoExeTaskServiceBiz autoExeTaskServiceBiz;
    @Resource
    private AutoExeTaskHisServiceBiz autoExeTaskHisServiceBiz;
    @Resource
    private CurrTaskServiceBiz currTaskServiceBiz;
    @Resource
    private ApmsController apmsController;
    @Override
    public R<AutoTaskVo> get(IdParam idParam) {
        Assert.notNull(ApiErrorCode.INVALID_PARAMETER,idParam.getId());
        AutoExeTask autoExeTask=autoExeTaskServiceBiz.getById(idParam.getId());
        AutoTaskVo autoTaskVo=AutoTaskVo.builder().build();
        org.springframework.beans.BeanUtils.copyProperties(autoExeTask,autoTaskVo);
        return successful(autoTaskVo);
    }

    @Override
    public R<List<AutoTaskVo>> list(AutoTaskQueryParam autoTaskQueryParam) {
        return null;
    }

    @Override
    public R<PageVo<AutoTaskVo>> page(AutoTaskQueryParam autoTaskQueryParam) {
        QueryWrapper<AutoExeTask> wrapper=new QueryWrapper<>();
        wrapper.eq((autoTaskQueryParam.getStatus()!=null&&("").equals(autoTaskQueryParam.getStatus())),AutoExeTask.STATUS,autoTaskQueryParam.getStatus());
        wrapper.in(AutoExeTask.STATUS,0,1);
        Page<AutoExeTask> page = autoExeTaskServiceBiz.page(new Page<>(autoTaskQueryParam.getCurrent(), autoTaskQueryParam.getSize()), wrapper);
        return successful(new PageVo<>(page,AutoTaskVo.class));
    }

    @Override
    public R<IdVo> stop(IdParam idParam) {

        AutoExeTask autoExeTask = autoExeTaskServiceBiz.getById(idParam.getId());
        //状态置为终止
        autoExeTask.setStatus(3);
        autoExeTaskServiceBiz.updateById(autoExeTask);
        //记录到自动任务历史表
        AutoExeTaskHis autoExeTaskHis=new AutoExeTaskHis();
        BeanUtils.copyProperties(autoExeTask,autoExeTaskHis);
        autoExeTaskHisServiceBiz.save(autoExeTaskHis);
        //释放后续步骤
        // TODO: 2022/3/3
            //删除对应的几条currtask(未执行的),通知apms生产单作废
            List<CurrTask> currTaskList = currTaskServiceBiz.list(new QueryWrapper<CurrTask>()
                    .eq(CurrTask.AUTO_EXE_TASK_ID, autoExeTask.getId()).eq(CurrTask.STATUS,0));
            for (CurrTask currTask:currTaskList
                 ) {
                R<ApmsEndProcessVo> apmsEndProcessVoR = apmsController.deleteBySheetNo(currTask.getSheetNo());
                if (!apmsEndProcessVoR.getData().getSuccess()){
                    logger.info("Apms作废生产单接口错误");
                    return R.failed("Apms作废生产单接口错误");
                }
                currTaskServiceBiz.removeById(currTask);
            }
        autoExeTaskServiceBiz.removeById(autoExeTask);
        return successful(IdVo.builder().id(idParam.getId()).build());
    }
}
