package com.mt.wms.empty.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mt.wms.core.base.BaseService;
import com.mt.wms.core.dal.entity.AutoExeTask;
import com.mt.wms.core.dal.entity.CurrTaskDet;
import com.mt.wms.core.dal.entity.OrderInfo;
import com.mt.wms.core.dal.service.AutoExeTaskServiceBiz;
import com.mt.wms.core.dal.service.CurrTaskDetServiceBiz;
import com.mt.wms.core.dal.service.OrderInfoServiceBiz;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.utils.BeanUtils;
import com.mt.wms.core.utils.IDGenerator;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import com.mt.wms.empty.params.CurrTaskDetQueryParam;
import com.mt.wms.empty.params.OrderInfoTaskDetParam;
import com.mt.wms.empty.params.TaskCreateDetParam;
import com.mt.wms.empty.service.CurrTaskDetService;
import com.mt.wms.empty.service.CurrTaskService;
import com.mt.wms.empty.vo.CurrTaskDetVo;
import com.mt.wms.empty.vo.CurrTaskVo;
import com.mt.wms.empty.vo.OrderInfoTaskDetVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

/**
 * 服务实现类
 *
 * @author xcc
 * @date 2021年11月8日
 * @since 1.0
 */
@Service
@Transactional
public class CurrTaskDetServiceImpl extends BaseService implements CurrTaskDetService {

    @Autowired
    CurrTaskDetServiceBiz currTaskDetServiceBiz;
    @Autowired
    CurrTaskService currTaskService;
    @Autowired
    OrderInfoServiceBiz orderInfoService;
    @Autowired
    AutoExeTaskServiceBiz autoExeTaskServiceBiz;

    @Override
    public PageVo<OrderInfoTaskDetVo> getCurrOrderCurrTask(OrderInfoTaskDetParam param) {
        QueryWrapper<CurrTaskDet> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(CurrTaskDet.IDEN_CARD_NUM, param.getIdenCardNum())
                .eq(CurrTaskDet.ORDER_NO, param.getOrderNo())
                .eq(CurrTaskDet.VALID, 1);
        Page<CurrTaskDet> page = currTaskDetServiceBiz.page(new Page<>(param.getCurrent(), param.getSize()), queryWrapper);
        return new PageVo<>(page, OrderInfoTaskDetVo.class);
    }

    @Override
    public void createProcessTaskDet(List<TaskCreateDetParam> taskDet, Long taskId) {
        List<CurrTaskDet> params = BeanUtils.copyList(taskDet, CurrTaskDet.class);
        params.forEach(param -> {
            param.setCurrTaskId(taskId);
            param.setInterCode(IDGenerator.gen("RWDET", IDGenerator.PATTERN_YYYYMMDDHHMM, 2, "TASK_DET_CODE"));
            setCommonField(param);
        });
        currTaskDetServiceBiz.saveBatch(params);
    }

    @Override
    public R<PageVo<CurrTaskDetVo>> getTaskDetailsPage(CurrTaskDetQueryParam currTaskId) {
        QueryWrapper<CurrTaskDet> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(CurrTaskDet.CURR_TASK_ID, currTaskId.getCurrTaskId())
                .eq(CurrTaskDet.VALID, 1);
        Page<CurrTaskDet> page = currTaskDetServiceBiz.page(new Page<>(currTaskId.getCurrent(), currTaskId.getSize()), queryWrapper);
        PageVo<CurrTaskDetVo> currTaskDetVo = new PageVo<>(page, CurrTaskDetVo.class);
        currTaskDetVo.getRecords().forEach(
                e -> {
                    OrderInfo one = orderInfoService.getOne(new QueryWrapper<OrderInfo>().eq(OrderInfo.IDEN_CARD_NUM, e.getIdenCardNum()));
                    e.setProductModel(one.getProductModel());
                    e.setCustomer(one.getCustomerName());
                    e.setCraftIll(orderInfoService.getOne(new QueryWrapper<OrderInfo>().eq(OrderInfo.IDEN_CARD_NUM,e.getIdenCardNum())).getCraftIll());
                }
        );
        return successful(currTaskDetVo);
    }

    @Override
    public List<CurrTaskDet> getTaskDetailsByMainId(IdParam idParam) {
        QueryWrapper<CurrTaskDet> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(CurrTaskDet.CURR_TASK_ID, idParam.getId())
                .eq(CurrTaskDet.VALID, 1);
        return currTaskDetServiceBiz.list(queryWrapper);
    }

    @Override
    public List<CurrTaskDet> getTaskDetailsByIdenCardNum(String idenCardNum) {
        QueryWrapper<CurrTaskDet> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(CurrTaskDet.IDEN_CARD_NUM, idenCardNum)
                .eq(CurrTaskDet.VALID, 1);
        return currTaskDetServiceBiz.list(queryWrapper);
    }

    @Override
    public R<String> deleteByCurrTaskId(Long currTaskId) {
        currTaskDetServiceBiz.remove(new QueryWrapper<CurrTaskDet>().eq(CurrTaskDet.CURR_TASK_ID, currTaskId));
        return successful("成功。");
    }

    @Override
    public HashMap<String, Double> getSumByIdCard(String idCard) {
        HashMap<String, Double> result = new HashMap<>(2);
        QueryWrapper<CurrTaskDet> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(CurrTaskDet.IDEN_CARD_NUM, idCard)
                .eq(CurrTaskDet.VALID, 1);
        List<CurrTaskDet> list = currTaskDetServiceBiz.list(queryWrapper);
        Iterator<CurrTaskDet> iterator=list.iterator();
        while (iterator.hasNext()){
            CurrTaskDet currTaskDet = iterator.next();
            CurrTaskVo byId = currTaskService.getCurrTask(IdParam.builder().id(currTaskDet.getCurrTaskId()).build());
            //如果加工类型是复加工，或者任务作废。移除对象
            if (byId.getProcessType().equals(2) || byId.getValid() != 1)
            {
                iterator.remove();
            }
            //如果是多步骤任务且不是第一步,移除对象
            if (byId.getIsAuto()==1){
                AutoExeTask autoExeTask = autoExeTaskServiceBiz.getById(byId.getAutoExeTaskId());
                if (!byId.getId().equals(autoExeTask.getFTaskId())){
                    iterator.remove();
                }
            }
        }
/*        list.forEach(e -> {
            CurrTaskVo byId = currTaskService.getCurrTask(IdParam.builder().id(e.getCurrTaskId()).build());
            //如果加工类型是复加工，或者任务作废。移除对象
            if (byId.getProcessType().equals(2) || byId.getValid() != 1)
            {
                list.remove(e);
            }
            //如果是多步骤任务且不是第一步,移除对象
            if (byId.getIsAuto()==1){
                AutoExeTask autoExeTask = autoExeTaskServiceBiz.getById(byId.getAutoExeTaskId());
                if (!byId.getId().equals(autoExeTask.getFTaskId())){
                    list.remove(e);
                }
            }
        });*/
        //计算加工总数
        double sumWeight = list.stream().mapToDouble(CurrTaskDet::getWeight).sum();
        double sumQuantity = list.stream().mapToDouble(CurrTaskDet::getQuantity).sum();
        result.put("weight", sumWeight);
        result.put("quantity", sumQuantity);
        return result;
    }
}
