/*
 * Copyright (c) 2018.
 * http://www.ulabcare.com
 */

package com.mt.wms.upms.controller;

import com.mt.wms.core.constants.CommonConstant;
import com.mt.wms.core.base.BaseController;
import com.mt.wms.core.params.EnabledParam;
import com.mt.wms.core.params.IdListParam;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.validator.groups.AddGroup;
import com.mt.wms.core.validator.groups.PageGroup;
import com.mt.wms.core.validator.groups.UpdateGroup;
import com.mt.wms.core.vo.IdListVo;
import com.mt.wms.core.vo.IdVo;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import com.mt.wms.upms.params.ResourceParam;
import com.mt.wms.upms.params.ResourceQueryParam;
import com.mt.wms.upms.service.ResourceService;
import com.mt.wms.upms.vo.ResourceVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.groups.Default;
import java.util.List;

/**
 * 平台资源控制器
 *
 * @author jiff
 * @date 2018/11/14
 * @since 1.0
 */
@RestController
@RequestMapping(CommonConstant.API_MODULE_UPMS +"resource")
@Slf4j
@Api(value = "平台资源管理", description = "平台资源管理接口", hidden = false)
public class ResourceController extends BaseController {
    @Autowired
    private ResourceService resourceService;

    @PostMapping(value = "get")
    @ApiOperation(value = "获取资源")
    private R<ResourceVo> get(@Validated @RequestBody IdParam idParam) {
        return resourceService.get(idParam);
    }

    @PostMapping(value = "page")
    @ApiOperation(value = "获取分页资源列表")
    private R<PageVo<ResourceVo>> page(@Validated({PageGroup.class, Default.class}) @RequestBody ResourceQueryParam resourceQueryParam) {
        return resourceService.page(resourceQueryParam);
    }

    @PostMapping(value = "list")
    @ApiOperation(value = "获取资源列表")
    private R<List<ResourceVo>> list(@Validated({Default.class}) @RequestBody ResourceQueryParam resourceQueryParam) {
        return resourceService.list(resourceQueryParam);
    }

    @PostMapping(value = "add")
    @ApiOperation(value = "新增资源")
    private R<IdVo> add(@Validated({AddGroup.class, Default.class}) @RequestBody ResourceParam resourceParam) {
        return resourceService.add(resourceParam);
    }

    @PostMapping(value = "update")
    @ApiOperation(value = "更新资源")
    private R<IdVo> update(@Validated({UpdateGroup.class, Default.class}) @RequestBody ResourceParam resourceParam) {
        return resourceService.update(resourceParam);
    }

    @PostMapping(value = "enabled")
    @ApiOperation(value = "启停资源")
    private R<IdVo> enabled(@Validated @RequestBody EnabledParam enabledParam) {
        return resourceService.enabled(enabledParam);
    }


    @PostMapping(value = "delete")
    @ApiOperation(value = "删除资源")
    private R<IdVo> delete(@Validated @RequestBody IdParam idParam) {
        return resourceService.delete(idParam);
    }

    @PostMapping(value = "batchDelete")
    @ApiOperation(value = "批量删除资源")
    private R<IdListVo> delete(@Validated @RequestBody IdListParam idListParam) {
        return resourceService.delete(idListParam);
    }
}
